# Cauchy

Sometimes, instrument response function is modeled as normalized cauchy distribution.

\begin{equation*}
{IRF}(t) = \frac{\gamma}{\pi} \frac{1}{(x-t)^2+\gamma^2}
\end{equation*}

Full Width at Half Maximum (fwhm) is $2\gamma$.

